import 'package:flutter/material.dart';
import 'dart:async';
import 'package:path/path.dart';
import 'package:sqflite/sqflite.dart';


class Sqlite3Helper {

  Sqlite3Helper._();

  static Sqlite3Helper _instance;

  static Sqlite3Helper create() {
    if (_instance == null) {
      _instance = Sqlite3Helper._();
    }
    return _instance;
  }
  
  static Future<Database> database;

  ///
  /// 初始化数据库
  ///
  Future<int> init() async{
    database = openDatabase(
      join(await getDatabasesPath(), 'xx_database.db'),
      onCreate: (db, version) {
        return db.execute('CREATE TABLE IF NOT EXISTS Statistical(id TEXT NOT NULL, event INT,type INT,amount INT)');
      },
      version: 1
    );
    if(database == null){
      print('==========>数据为空');
      return Future.value(0);
    }else{
      return await queryCount();
    }
  }

  ///
  /// 添加数据
  ///
  void add({@required String id,int event,int type,int amount=1}) async{
    if(database != null){
      final db = await database;
      String sql = 'INSERT INTO Statistical(id,event,type,amount) VALUES(?,?,?,?)';
      await db.execute(sql,[id,event,type,amount]);
    }
  }

  ///
  /// 查询所有数据并根据id,event,type进行计数
  ///
  Future<List<Map<String, dynamic>>> query() async{
    if(database != null){
      final db = await database;
      String sql = 'select id,event,type,COUNT(amount) as amount FROM Statistical GROUP BY id,event,type';
      List<Map<String, dynamic>> results = await db.rawQuery(sql);
      return results;
    }
    return Future.value([]);
  }

  ///
  /// 查询数据库记录了多少条数据
  ///  
  Future<int> queryCount() async {
    if(database != null){
      final db = await database;
      String sql = 'select COUNT(*) as amount FROM Statistical';
      final List<Map<String, dynamic>> maps = await db.rawQuery(sql);
      if(maps!=null && maps.length>0){
        Map<String, dynamic> data =maps[0];
        if(data['amount'] is int){
          return data['amount'];
        }
      }
    }
    return 0;
  }

  ///
  /// 删除所有数据
  ///
  Future<int> deleteAll() async{
     if(database != null){
       final db = await database;
       int number = await db.delete('Statistical');
       return number;
     }
    return Future.value(0);
  }
}